# Table of contents

* [Swan](README.md)

## Tutorials

* [Getting started](tutorials/getting_started.md)
* [Visualization](tutorials/visualization.md)
* [Analysis](tutorials/analysis_tools.md)

## FAQs

* [Understanding Swan visualizations](faqs/understanding_swan_vis.md)
* [File format specifications](faqs/file_formats.md)

## Code documentation

* [swan\_vis.SwanGraph\(\)](code-documentation/swangraph.md)

